Transaction class

Constructors

Transaction(double amount, String currencyCode, String customerName, String customerEmail, String paymentReference, String paymentDescription, {Map<String, String> metaData = const {}, List<PaymentMethod> paymentMethods = const [], List<SubAccountDetails> incomeSplitConfig = const []})

Properties

amount ↔ double
getter/setter pair
currencyCode ↔ String
getter/setter pair
customerEmail ↔ String
getter/setter pair
customerName ↔ String
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
incomeSplitConfig ↔ List<SubAccountDetails>
getter/setter pair
metaData ↔ Map<String, String>
getter/setter pair
paymentDescription ↔ String
getter/setter pair
paymentMethods ↔ List<PaymentMethod>
getter/setter pair
paymentReference ↔ String
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited